aboutsummaryrefslogtreecommitdiff
path: root/classes/constants.php
diff options
context:
space:
mode:
Diffstat (limited to 'classes/constants.php')
-rw-r--r--classes/constants.php6
1 files changed, 5 insertions, 1 deletions
diff --git a/classes/constants.php b/classes/constants.php
index 77f47b0..e5630de 100644
--- a/classes/constants.php
+++ b/classes/constants.php
@@ -69,7 +69,11 @@ class constants {
/** @const fa_valuta see http://fontawesome.io/icons/#currency; the fa- postfix for valuta */
const fa_valuta = 'eur';
- /** @const password_cost for the password_hash function. Run install?password_cost to benchmark your system */
+ /**
+ * @const password_algo Algorithm for the password_hash function.
+ * @const password_cost Cost for the password_hash function. Run install?password_cost to benchmark your system
+ */
+ const password_algo = PASSWORD_DEFAULT;
const password_cost = 10;
/** @const version Version of BusinessAdmin. Don't change this yourself! */